@@ -3,7 +3,7 @@ The ``mlflow.entities`` module defines entities returned by the MLflow
 `REST API <../rest-api.html>`_.
 """
 
-from mlflow.entities.auth_enums import EntityType, Role, SubjectType
+from mlflow.entities.auth_enums import EntityType, PrivacyType, Role, SubjectType
 from mlflow.entities.columns import Columns
 from mlflow.entities.entity_subject_role import EntitySubjectRole
 from mlflow.entities.experiment import Experiment
@@ -15,7 +15,7 @@ from mlflow.entities.param import Param
 from mlflow.entities.run import Run
 from mlflow.entities.run_data import RunData
 from mlflow.entities.run_info import RunInfo
-from mlflow.entities.run_log import RunLog
+from mlflow.entities.run_log import LatestRunLog, RunLog
 from mlflow.entities.run_status import RunStatus
 from mlflow.entities.run_tag import RunTag
 from mlflow.entities.sentinel import SENTINEL
@@ -43,4 +43,6 @@ __all__ = [
     "Columns",
     "RunLog",
     "SENTINEL",
+    "LatestRunLog",
+    "PrivacyType",
 ]
