@@ -1,7 +1,15 @@
 import typing
 from abc import ABCMeta, abstractmethod
 
-from mlflow.entities import Columns, Metric, Run, RunLog, ViewType
+from mlflow.entities import (
+    Columns,
+    LatestRunLog,
+    Metric,
+    Run,
+    RunInfo,
+    RunLog,
+    ViewType,
+)
 from mlflow.store.entities.paged_list import PagedList
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 
@@ -344,7 +352,11 @@ class AbstractStore:
         raise NotImplementedError()
 
     def list_run_logs(
-        self, run_uuid: str, key: typing.Optional[str], log_type: typing.Optional[str]
+        self,
+        run_uuid: str,
+        key: typing.Optional[str],
+        log_type: typing.Optional[str],
+        steps: typing.Optional[typing.List[int]],
     ) -> typing.List[RunLog]:
         raise NotImplementedError()
 
@@ -353,3 +365,14 @@ class AbstractStore:
 
     def update_experiment(self, experiment_id: str, description: typing.Optional[str]):
         raise NotImplementedError()
+
+    def get_run_info(self, run_id: str) -> RunInfo:
+        raise NotImplementedError()
+
+    def list_latest_run_logs(
+        self,
+        run_uuid: str,
+        key: typing.Optional[str] = None,
+        log_type: typing.Optional[str] = None,
+    ) -> typing.List[LatestRunLog]:
+        raise NotImplementedError()
