@@ -481,9 +481,13 @@ class TrackingServiceClient:
         return self.store.get_latest_run_log(run_uuid=run_uuid, key=key, log_type=log_type)
 
     def list_run_logs(
-        self, run_uuid: str, key: typing.Optional[str] = None, log_type: typing.Optional[str] = None
+        self,
+        run_uuid: str,
+        key: typing.Optional[str] = None,
+        log_type: typing.Optional[str] = None,
+        steps: typing.Optional[typing.List[int]] = None,
     ) -> typing.List[RunLog]:
-        return self.store.list_run_logs(run_uuid=run_uuid, key=key, log_type=log_type)
+        return self.store.list_run_logs(run_uuid=run_uuid, key=key, log_type=log_type, steps=steps)
 
     def get_run_by_fqn(self, fqn: str) -> Run:
         return self.store.get_run_by_fqn(fqn=fqn)
